==> haskell-simple-sendfile-0.2.27-62-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: simple-sendfile
version: 0.2.27
id: simple-sendfile-0.2.27-KRKlMiPFOZvCkqh7OC0lee
key: simple-sendfile-0.2.27-KRKlMiPFOZvCkqh7OC0lee
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.
category: Network
abi: e86225e96c3d715abc3825a31ae54ec6
exposed: True
exposed-modules:
    Network.Sendfile System.Linux.Sendfile
hidden-modules: Network.Sendfile.Types Network.Sendfile.Linux
import-dirs: /usr/lib/ghc-8.4.3/site-local/simple-sendfile-0.2.27
library-dirs: /usr/lib/ghc-8.4.3/site-local/simple-sendfile-0.2.27
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/simple-sendfile-0.2.27
hs-libraries: HSsimple-sendfile-0.2.27-KRKlMiPFOZvCkqh7OC0lee
depends:
    base-4.11.1.0 network-2.7.0.2-3zQTN3hKcaz6IkeyUSsRrW
    bytestring-0.10.8.2 unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             network-2.7.0.2-3zQTN3hKcaz6IkeyUSsRrW=69b658fb7f59eb9acbefe047d83e7e11
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
haddock-interfaces: /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock
haddock-html: /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-simple-sendfile-0.2.27-66-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: simple-sendfile
version: 0.2.27
id: simple-sendfile-0.2.27-H6PBQcSHqPQBuE4CfM79e2
key: simple-sendfile-0.2.27-H6PBQcSHqPQBuE4CfM79e2
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.
category: Network
abi: 6e8be8d13c4c6642f14348c754b382d1
exposed: True
exposed-modules:
    Network.Sendfile System.Linux.Sendfile
hidden-modules: Network.Sendfile.Types Network.Sendfile.Linux
import-dirs: /usr/lib/ghc-8.4.3/site-local/simple-sendfile-0.2.27
library-dirs: /usr/lib/ghc-8.4.3/site-local/simple-sendfile-0.2.27
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/simple-sendfile-0.2.27
hs-libraries: HSsimple-sendfile-0.2.27-H6PBQcSHqPQBuE4CfM79e2
depends:
    base-4.11.1.0 network-2.7.0.2-6FfBvmD6NTeAPSa47HXiSR
    bytestring-0.10.8.2 unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             network-2.7.0.2-6FfBvmD6NTeAPSa47HXiSR=614b1a60f3013422c23df99507b7d70f
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
haddock-interfaces: /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock
haddock-html: /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
